v1.2.1
======

#1: Fix TypeError on Python 3 in gzip handler.

v1.2.0
======

Ensure options such as readPreference, if included in the URL,
are honored by the MongoClient.

v1.1.0
======

Python 3 support.
Basic test suite and CI config.
